==> 2.5.0.zip: cloudlog/application/language/finnish/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Varoitus: sinun täytyy valita aktiivinen asemaprofiili.';

$lang['notice_turn_the_radio_on'] = 'Ei kusoja tänään - siis radio päälle ja bandeille!';

$lang['general_word_important'] = 'Tärkeää';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Valitse tiedosto';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";

$lang['general_word_date'] = 'Päivä';
$lang['general_word_time'] = 'Aika';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Päivä/Aika';
$lang['general_word_none'] = 'None';
$lang['general_word_name'] = 'Nimi';
$lang['general_word_location'] = 'Sijainti';
$lang['general_word_comment'] = 'Kommentti';
$lang['general_word_general'] = 'Yleinen';
$lang['general_word_satellite'] = 'Satelliitti';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Muistiinpanot';
$lang['general_word_country'] = 'Maa';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Yhteensä';
$lang['general_word_year'] = 'Vuosi';
$lang['general_word_month'] = 'Kuukausi';

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Workittu';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Kuitattu';
$lang['general_word_needed'] = 'Tarvittu';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Ei';
$lang['general_word_yes'] = 'Kyllä';
$lang['general_word_method'] = 'Method / tapa';

$lang['general_word_sent'] = 'Lähetetyt';
$lang['general_word_received'] = 'Vastaanotetut';
$lang['general_word_requested'] = 'Pyydetyt';
$lang['general_word_queued'] = 'Queued';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Virheellinen (Ohita)';
$lang['general_word_qslcard'] = 'QSL-kortti';
$lang['general_word_qslcard_management'] = 'QSL-manageri';
$lang['general_word_qslcards'] = 'QSL-kortit';
$lang['general_word_qslcard_direct'] = 'Direct';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Electronic';
$lang['general_word_qslcard_manager'] = 'Manageri';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Muokkaa QSO:a';
$lang['general_mark_qsl_rx_bureau'] = 'Merkitse QSL vastaanotetuksi (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Merkitse QSL vastaanotetuksi (Direct)';
$lang['general_mark_qsl_rx_electronic'] = 'Merkitse QSL vastaanotetuksi (Electronic)';
$lang['general_mark_qsl_tx_bureau'] = 'Merkitse QSL lähetetyksi (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Merkitse QSL lähetetyksi (Direct)';
$lang['general_mark_qsl_requested'] = 'Merkitse QSL-kortti pyydetyksi';
$lang['general_mark_qsl_requested_bureau'] = 'Merkitse QSL-kortti pyydetyksi (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Merkitse QSL-kortti pyydetyksi (Direct)';
$lang['general_mark_qsl_not_required'] = 'Merkitse QSL-kortti tarpeettomaksi';

$lang['general_delete_qso'] = 'Poista QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Kokonaismatka';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Asemaprofiili';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Asema';

$lang['gen_hamradio_call'] = 'Kutsu';
$lang['gen_hamradio_callsign'] = 'Kutsumerkki';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Lähetelaji';
$lang['gen_hamradio_rst_sent'] = 'Annettu raportti';
$lang['gen_hamradio_rst_rcvd'] = 'Saatu raportti';
$lang['gen_hamradio_band'] = 'Bandi';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Bandi (RX)';
$lang['gen_hamradio_frequency'] = 'Taajuus';
$lang['gen_hamradio_frequency_rx'] = 'Taajuus (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Lokaattori';
$lang['gen_hamradio_transmit_power'] = 'Lähetysteho (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagaatiomuoto';

$lang['gen_hamradio_satellite_name'] = 'Satelliitti';
$lang['gen_hamradio_satellite_mode'] = 'Satelliitin Mode';

$lang['gen_hamradio_logbook'] = 'Lokikirja';

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Poistettu DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'USA:n osavaltio';
$lang['gen_hamradio_county_reference'] = 'USA lääni';
$lang['gen_hamradio_iota_reference'] = 'IOTA ref.nro';
$lang['gen_hamradio_sota_reference'] = 'SOTA ref.nro';
$lang['gen_hamradio_wwff_reference'] = 'WWFF ref.nro';
$lang['gen_hamradio_pota_reference'] = 'POTA ref.nro';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'osavaltio';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Gridsquare';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_distance'] = 'Etäisyys';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then ";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then ";
$lang['gen_find_zone_part2'] = 'click here';
$lang['gen_find_zone_part3'] = ' to find it!';

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Olet pitänyt';
$lang['dashboard_qsos_today'] = 'yhteyttä tänään!';
$lang['dashboard_qso_breakdown'] = 'Yhteystilasto';
$lang['dashboard_countries_breakdown'] = 'Maatilasto';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'päivämäärästä';

$lang['gen_this_qso_was_confirmed_on'] = 'Tämä QSO vahvistettiin';

$lang['error_no_logbook_found'] = 'No logbooks were found. You need to define a logbook under Station Logbooks! Do it here:';

$lang['copy_to_clipboard'] = 'Kopioi leikepöydälle';

$lang['africa'] = 'Afrikka';
$lang['antarctica'] = 'Antarktis';
$lang['asia'] = 'Aasia';
$lang['europe'] = 'Eurooppa';
$lang['northamerica'] = 'Pohjois-Amerikka';
$lang['oceania'] = 'Oseania';
$lang['southamerica'] = 'Etelä-Amerikka';

$lang['gen_band_selection'] = 'Bandin valinta';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

==> 2.6.4.zip: cloudlog/application/language/finnish/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Varoitus: sinun täytyy valita aktiivinen asemaprofiili.';

$lang['notice_turn_the_radio_on'] = 'Ei kusoja tänään - siis radio päälle ja bandeille!';

$lang['general_word_important'] = 'Tärkeää';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Valitse tiedosto';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";
$lang['general_word_count'] = "Count";
$lang['general_word_filtering_on'] = "Filtering on";
$lang['general_word_not_display'] = "Not display";
$lang['general_word_icon'] = "Icon";
$lang['general_word_never'] = "Never";

$lang['general_word_date'] = 'Päivä';
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";
$lang['general_word_time'] = 'Aika';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Päivä/Aika';
$lang['general_word_none'] = 'None';
$lang['general_word_name'] = 'Nimi';
$lang['general_word_location'] = 'Sijainti';
$lang['general_word_comment'] = 'Kommentti';
$lang['general_word_general'] = 'Yleinen';
$lang['general_word_satellite'] = 'Satelliitti';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Muistiinpanot';
$lang['general_word_country'] = 'Maa';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Yhteensä';
$lang['general_word_year'] = 'Vuosi';
$lang['general_word_month'] = 'Kuukausi';
$lang['general_word_day'] = "Day";
$lang['general_word_days'] = "Days";

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Workittu';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Kuitattu';
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_needed'] = 'Tarvittu';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Ei';
$lang['general_word_yes'] = 'Kyllä';
$lang['general_word_method'] = 'Method / tapa';

$lang['general_word_sent'] = 'Lähetetyt';
$lang['general_word_received'] = 'Vastaanotetut';
$lang['general_word_requested'] = 'Pyydetyt';
$lang['general_word_queued'] = 'Queued';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Virheellinen (Ohita)';
$lang['general_word_qslcard'] = 'QSL-kortti';
$lang['general_word_qslcard_management'] = 'QSL-manageri';
$lang['general_word_qslcards'] = 'QSL-kortit';
$lang['general_word_qslcard_direct'] = 'Direct';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Electronic';
$lang['general_word_qslcard_manager'] = 'Manageri';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Muokkaa QSO:a';
$lang['general_mark_qsl_rx_bureau'] = 'Merkitse QSL vastaanotetuksi (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Merkitse QSL vastaanotetuksi (Direct)';
$lang['general_mark_qsl_rx_electronic'] = 'Merkitse QSL vastaanotetuksi (Electronic)';
$lang['general_mark_qsl_tx_bureau'] = 'Merkitse QSL lähetetyksi (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Merkitse QSL lähetetyksi (Direct)';
$lang['general_mark_qsl_requested'] = 'Merkitse QSL-kortti pyydetyksi';
$lang['general_mark_qsl_requested_bureau'] = 'Merkitse QSL-kortti pyydetyksi (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Merkitse QSL-kortti pyydetyksi (Direct)';
$lang['general_mark_qsl_not_required'] = 'Merkitse QSL-kortti tarpeettomaksi';

$lang['general_delete_qso'] = 'Poista QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Kokonaismatka';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Asemaprofiili';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Asema';

$lang['gen_hamradio_call'] = 'Kutsu';
$lang['gen_hamradio_callsign'] = 'Kutsumerkki';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Lähetelaji';
$lang['gen_hamradio_rst_sent'] = 'Annettu raportti';
$lang['gen_hamradio_rst_rcvd'] = 'Saatu raportti';
$lang['gen_hamradio_band'] = 'Bandi';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Bandi (RX)';
$lang['gen_hamradio_frequency'] = 'Taajuus';
$lang['gen_hamradio_frequency_rx'] = 'Taajuus (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Lokaattori';
$lang['gen_hamradio_transmit_power'] = 'Lähetysteho (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagaatiomuoto';

$lang['gen_hamradio_satellite_name'] = 'Satelliitti';
$lang['gen_hamradio_satellite_mode'] = 'Satelliitin Mode';

$lang['gen_hamradio_logbook'] = 'Lokikirja';
$lang['gen_hamradio_award'] = "Award";

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Poistettu DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'USA:n osavaltio';
$lang['gen_hamradio_county_reference'] = 'USA lääni';
$lang['gen_hamradio_iota_reference'] = 'IOTA ref.nro';
$lang['gen_hamradio_sota_reference'] = 'SOTA ref.nro';
$lang['gen_hamradio_wwff_reference'] = 'WWFF ref.nro';
$lang['gen_hamradio_pota_reference'] = 'POTA ref.nro';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'osavaltio';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Gridsquare';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_gridsquare_show'] = "Show Locator";
$lang['gen_hamradio_latitude'] = "Latitude";
$lang['gen_hamradio_longitude'] = "Longitude";
$lang['gen_hamradio_bearing'] = "Bearing";
$lang['gen_hamradio_distance'] = 'Etäisyys';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then";
$lang['gen_find_zone_part2'] = "click here";
$lang['gen_find_zone_part3'] = "to find it!";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Olet pitänyt';
$lang['dashboard_qsos_today'] = 'yhteyttä tänään!';
$lang['dashboard_qso_breakdown'] = 'Yhteystilasto';
$lang['dashboard_countries_breakdown'] = 'Maatilasto';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'päivämäärästä';

$lang['gen_this_qso_was_confirmed_on'] = 'Tämä QSO vahvistettiin';

$lang['error_no_logbook_found'] = 'No logbooks were found. You need to define a logbook under Station Logbooks! Do it here:';

$lang['copy_to_clipboard'] = 'Kopioi leikepöydälle';

$lang['africa'] = 'Afrikka';
$lang['antarctica'] = 'Antarktis';
$lang['asia'] = 'Aasia';
$lang['europe'] = 'Eurooppa';
$lang['northamerica'] = 'Pohjois-Amerikka';
$lang['oceania'] = 'Oseania';
$lang['southamerica'] = 'Etelä-Amerikka';

$lang['gen_band_selection'] = 'Bandin valinta';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';

$lang['datatables_language'] = "en-GB";
